==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/archive.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
include("include/kmod/search/index.php");
if (!$CONF['Archive']) die(_DISABLED);
$head = _ARCHIVE;
include("include/header.inc.php");

$sql	= "SELECT UNIX_TIMESTAMP(Repostamp) AS TS ";
$sql	.= "from T_Stories WHERE Verified = 'Y' ORDER BY TS DESC";
$result = SqlQuery($sql);
$VAR["Heading"]	= _STORY . " " . _ARCHIVE;
$VAR["Content"]	= "<UL>\n";

$oldMonth = $tmp = "";
while ($A = mysql_fetch_array($result)) {
	$vm = strftime("%B",$A["TS"]);
	$m	= (double) strftime("%m",$A["TS"]);
	$y	= strftime("%Y",$A["TS"]);

	if ($oldMonth!=$vm) {
		if ($tmp != $y) $VAR["Content"] .= "<P>\n";
		$tmp = $y;

		$VAR["Content"] .= "<li><a href=\"$G_URL/archive.php?month=$m&year=$y\">";
		$VAR["Content"] .= $rdf_lang == "euc-kr" ? $y . "" . " " . $m . "" : $vm . " " . $y;
		$VAR["Content"] .= "</a></li>\n";
		$oldMonth = $vm;
	}
}
$VAR["Content"] .= "</UL>\n";
KWL_DrawMain($VAR);

if (isset($month) && isset($year)) {
   define("_ARCHIVE_RESULT","1");
   settype($month, "integer");
   settype($year, "integer");
	KWL_drawResults('',$_GET['month'],$_GET['year']);
}
include("include/footer.inc.php");
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/archive.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
include("include/kmod/search/index.php");
if (!$CONF['Archive']) die(_DISABLED);
$head = _ARCHIVE;
include("include/header.inc.php");

$sql	= "SELECT UNIX_TIMESTAMP(Repostamp) AS TS ";
$sql	.= "from T_Stories WHERE Verified = 'Y' ORDER BY TS DESC";
$result = SqlQuery($sql);
$VAR["Heading"]	= _STORY . " " . _ARCHIVE;
$VAR["Content"]	= "<ul>\n";

$oldMonth = $tmp = "";
while ($A = mysql_fetch_array($result)) {
	$vm = strftime("%B",$A["TS"]);
	$m	= (double) strftime("%m",$A["TS"]);
	$y	= strftime("%Y",$A["TS"]);

	if ($oldMonth!=$vm) {
		if ($tmp != $y) $VAR["Content"] .= "<p />\n";
		$tmp = $y;

		$VAR["Content"] .= "<li><a href=\"$G_URL/archive.php?month=$m&amp;year=$y" ."#result\">";
		$VAR["Content"] .= $rdf_lang == "euc-kr" ? $y . "" . " " . $m . "" : $vm . " " . $y;
		$VAR["Content"] .= "</a></li>\n";
		$oldMonth = $vm;
	}
}
$VAR["Content"] .= "</UL>\n";
KWL_DrawMain($VAR);

if (isset($month) && isset($year)) {
   define("_ARCHIVE_RESULT","1");
   settype($month, "integer");
   settype($year, "integer");
	KWL_drawResults('',$_GET['month'],$_GET['year']);
}
include("include/footer.inc.php");
?>
